@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2015 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include "settings.h"
 
 #include <QDomDocument>
+#include <qzregexp.h>
 
 extern QString kCreateNewsTableQuery;
 
@@ -483,8 +484,7 @@ void AddFeedWizard::getUrlDone(int result, int feedId, QString feedUrlStr,
     if (!isFeed) {
       QString str = QString::fromUtf8(data);
 
-      QRegExp rx("<link[^>]+(atom|rss)\\+xml[^>]+>",
-                 Qt::CaseInsensitive, QRegExp::RegExp2);
+      QzRegExp rx("<link[^>]+(atom|rss)\\+xml[^>]+>", Qt::CaseInsensitive);
       int pos = rx.indexIn(str);
       if (pos > -1) {
         str = rx.cap(0);
