@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2015 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -219,6 +219,9 @@ public:
   bool markReadClosingTab_;
   bool markReadMinimize_;
   bool showDescriptionNews_;
+  ENewsClickAction::Type newsSingleClickAction;
+  ENewsClickAction::Type newsDoubleClickAction;
+  ENewsClickAction::Type newsMiddleClickAction;
   bool alternatingRowColorsNews_;
   bool simplifiedDateTime_;
   bool notDeleteStarred_;
@@ -290,6 +293,7 @@ public slots:
   void showOptionDlg(int index = -1);
   void slotPlaceToTray();
   void slotActivationTray(QSystemTrayIcon::ActivationReason reason);
+  void slotTrayOpenNotifyTimer();
   void showWindows(bool trayClick = false);
   void quitApp();
   void myEmptyWorkingSet();
@@ -299,7 +303,7 @@ public slots:
   void slotUpdateStatus(int feedId, bool changed = true);
   void setNewsFilter(QAction*, bool clicked = true);
   void slotCloseTab(int index);
-  QWebPage *createWebTab(QUrl url = QUrl());
+  QWebPage *createWebTab(QUrl url = QUrl(), const QString &overrideHtml="");
   void feedsModelReload(bool checkFilter = false);
   void setStatusFeed(int feedId, QString status);
   void slotPrint(QWebFrame *frame = 0);
@@ -319,7 +323,7 @@ signals:
   void faviconRequestUrl(QString urlString, QString feedUrl);
   void signalIconFeedReady(QString feedUrl, QByteArray faviconData);
   void signalSetCurrentTab(int index, bool updateTab = false);
-  void signalShowNotification();
+  void signalShowNotification(bool bShowRecentNews=false);
   void signalRefreshInfoTray();
   void signalNextUpdate(bool finish);
   void signalRecountCategoryCounts();
@@ -413,9 +417,9 @@ private slots:
   void setCurrentTab(int index, bool updateCurrentTab = false);
   void findText();
 
-  void showNotification();
+  void showNotification(bool bShowRecentNews=false);
   void deleteNotification();
-  void clearNotification();
+  void clearNotification(bool bClearRecentNews=false);
   void slotOpenNew(int feedId, int newsId);
   void slotOpenNewBrowser(const QUrl &url);
   void slotMarkReadNewsInNotification(int feedId, int newsId, int read);
@@ -725,12 +729,20 @@ private:
   bool cleanUpDeleted_;
   bool optimizeDB_;
 
-  int updateFeedsCount_;
-  QList<int> idFeedList_;
-  QList<int> cntNewNewsList_;
+  struct NewNewsData
+  {
+    QList<int> idFeedList_;
+    QList<int> cntNewsList_;
+  };
+
+  NewNewsData newNews;
+  NewNewsData recentNews;
+
   QList<int> idColorList_;
   QStringList colorList_;
 
+  QTimer timerTrayOpenNotify;
+
   bool reopenFeedStartup_;
   bool openNewTabNextToActive_;
 
