@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2015 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -25,10 +25,10 @@
 #include <QDebug>
 #include <QDesktopServices>
 #include <QTextDocumentFragment>
-#include <QRegExp>
 #if defined(Q_OS_WIN)
 #include <windows.h>
 #endif
+#include <qzregexp.h>
 
 ParseObject::ParseObject(QObject *parent)
   : QObject(parent)
@@ -142,8 +142,7 @@ void ParseObject::slotParse(const QByteArray &xmlData, const int &feedId,
   int errorLine;
   int errorColumn;
 
-  QRegExp rx("encoding=\"([^\"]+)",
-             Qt::CaseInsensitive, QRegExp::RegExp2);
+  QzRegExp rx("encoding=\"([^\"]+)", Qt::CaseInsensitive);
   int pos = rx.indexIn(xmlData);
   if (pos == -1) {
     rx.setPattern("encoding='([^']+)");
@@ -800,6 +799,8 @@ QString ParseObject::parseDate(const QString &dateString, const QString &urlStri
 
     temp = ds.left(20);
     timeZone = ds.mid(temp.length()+1, 3);
+    if (timeZone.contains("EDT"))
+      timeZone="-4";
     if (timeZone.isEmpty()) timeZone = QString::number(nTimeShift);
     dt = locale.toDateTime(temp, "dd MMM yyyy HH:mm:ss");
     if (dt.isValid()) return locale.toString(dt.addSecs(timeZone.toInt() * -3600), "yyyy-MM-ddTHH:mm:ss");
